@@ -112,14 +112,17 @@ def col_name2cat(column):
     return column_string
 
 
-def apply_pastml_to_all_columns(tree, df, columns, work_dir, res_annotations, sep='\t', model='JC', copy_columns=None,
-                                cache=False):
+def get_ancestral_states_for_all_columns(tree, df, columns, work_dir, res_annotations, sep='\t', model='JC',
+                                         copy_columns=None, cache=False):
     """
-    Applies PASTML as many times as there are categories (columns) in the data,
-    infers ancestor states and reformats them into an output tab/csv file.
+    Creates a table with node states by applying PASTML to infer ancestral states for categories specified in columns,
+    and copying the states from copy_columns.
+    :param cache: bool, if True the results of previous PASTML runs on this data will be reused when possible.
+    :param columns: list of columns to be processed with PASTML.
+    :param copy_columns: list of columns to be copied as-is.
     :param model: str (optional, default is 'JC'), model to be used by PASTML.
     :param tree: str, path to the tree in newick format.
-    :param data: pandas.DataFrame containing tree tip names as indices and categories as columns.
+    :param df: pandas.DataFrame containing tree tip names as indices and categories as columns.
     :param work_dir: str, path to the working dir where PASTML can place its temporary files.
     :param res_annotations: str, path to the file where the output table will be created.
     :param sep: char (optional, by default '\t'), the column separator for the output table.
@@ -167,20 +170,26 @@ def pastml_pipeline(tree, data, out_data=None, html_compressed=None, html=None,
                     verbose=False, cache=False):
     """
     Applies PASTML to the given tree with the specified states and visualizes the result (as html maps).
+    :param copy_columns: list of str (optional), names of the data table columns that contain states to be copied as-is,
+    without applying PASTML (the missing states will stay unresolved).
+    :param cache: bool, if True the results of previous PASTML runs on this data will be reused when possible.
+    :param verbose: bool, print information on the progress of the analysis.
+    :param out_data: str, path to the output annotation file with the states inferred by PASTML.
     :param tree: str, path to the input tree in newick format.
     :param data: str, path to the annotation file in tab/csv format with the first row containing the column names.
     :param html_compressed: str, path where the output summary map visualisation file (html) will be created.
     :param html: str (optional), path where the output tree visualisation file (html) will be created.
     :param data_sep: char (optional, by default '\t'), the column separator for the data table.
     By default is set to tab, i.e. for tab file. Set it to ',' if your file is csv.
-    :param id_index: int (optional, by default is 0) the index of the column in the data table that contains the tree tip names,
-    indices start from zero.
-    :param columns: array of str (optional), names of the data table columns that contain states to be analysed with PASTML,
-    if not specified all columns will be considered.
+    :param id_index: int (optional, by default is 0) the index of the column in the data table
+    that contains the tree tip names, indices start from zero.
+    :param columns: list of str (optional), names of the data table columns that contain states
+    to be analysed with PASTML, if not specified all columns will be considered.
     :param name_column: str (optional), name of the data table column to be used for node names in the visualisation
     (must be one of those specified in columns, if columns are specified). If the data table contains only one column,
     it will be used by default.
-    :param work_dir: str (optional), path to the working dir for PASTML (if not specified a temporary dir will be created).
+    :param work_dir: str (optional), path to the working dir for PASTML
+    (if not specified a temporary dir will be created).
     :param all: bool (optional, by default is False), if to keep all the nodes in the map, even the minor ones.
     :param model: str (optional, default is 'JC'), model to be used by PASTML.
     :return: void
@@ -198,8 +207,8 @@ def pastml_pipeline(tree, data, out_data=None, html_compressed=None, html=None,
 
     df = pd.read_table(data, sep=data_sep, index_col=id_index, header=0)
 
-    unknown_columns = ((set(columns) if columns else set()) | (set(copy_columns) if copy_columns else set())) \
-                      - set(df.columns)
+    unknown_columns = ((set(columns) if columns else set())
+                       | (set(copy_columns) if copy_columns else set())) - set(df.columns)
     if unknown_columns:
         raise ValueError('{} of the specified columns ({}) {} not found among the annotation columns: {}.'
                          .format('One' if len(unknown_columns) == 1 else 'Some',
@@ -233,36 +242,19 @@ def pastml_pipeline(tree, data, out_data=None, html_compressed=None, html=None,
     else:
         root = read_tree(new_tree)
 
-    apply_pastml_to_all_columns(tree=new_tree, df=df, columns=columns, work_dir=work_dir,
-                                res_annotations=res_annotations,
-                                sep=data_sep, model=model, copy_columns=copy_columns, cache=cache)
+    get_ancestral_states_for_all_columns(tree=new_tree, df=df, columns=columns, work_dir=work_dir,
+                                         res_annotations=res_annotations,
+                                         sep=data_sep, model=model, copy_columns=copy_columns, cache=cache)
 
-    past_vis(root, res_annotations, html_compressed, html, data_sep=data_sep,
-             columns=(columns + copy_columns) if copy_columns else columns, name_column=name_column, all=all)
+    _past_vis(root, res_annotations, html_compressed, html, data_sep=data_sep,
+              columns=(columns + copy_columns) if copy_columns else columns, name_column=name_column, all=all)
 
     if using_temp_dir:
         shutil.rmtree(work_dir)
 
 
-def past_vis(tree, res_annotations, html_compressed=None, html=None, data_sep='\t', columns=None, name_column=None,
-             all=False):
-    """
-    Applies PASTML to the given tree with the specified states and visualizes the result (as html maps).
-    :param tree: ete3.Tree, the tree of interest.
-    :param html_compressed: str, path where the output summary map visualisation file (html) will be created.
-    :param html: str (optional), path where the output tree visualisation file (html) will be created.
-    :param data_sep: char (optional, by default '\t'), the column separator for the annotation table.
-    By default is set to tab, i.e. for tab file. Set it to ',' if your file is csv.
-    :param columns: array of str, names of the data table columns that contain states to be analysed with PASTML.
-    :param name_column: str (optional), name of the data table column to be used for node names in the visualisation
-    (must be one of those specified in columns, if columns are specified). If columns contain only one column,
-    it will be used by default.
-    :param for_names_only: bool (optional, by default is False) If is set to True, and we are to analyse multiple states
-    (specified in columns),and the name_column is specified,
-    then the name_column won't be assigned a coloured section on the nodes, but will only be shown as node names.
-    :param all: bool (optional, by default is False), if to keep all the nodes in the map, even the minor ones.
-    :return: void
-    """
+def _past_vis(tree, res_annotations, html_compressed=None, html=None, data_sep='\t', columns=None, name_column=None,
+              all=False):
     one_column = len(columns) == 1
     tree, categories = annotate_tree_with_cyto_metadata(tree, res_annotations, sep=data_sep, one_state=one_column)
 
@@ -292,12 +284,11 @@ def past_vis(tree, res_annotations, html_compressed=None, html=None, data_sep='\
             name2colour['{}_{}'.format(cat, True)] = col
 
     if one_column:
-        n2tooltip = lambda n, categories: ', '.join('{}'.format(cat) for cat in categories
-                                                    if hasattr(n, cat) and bool(getattr(n, cat, False)))
+        n2tooltip = lambda n, cats: ', '.join('{}'.format(_) for _ in cats
+                                              if hasattr(n, _) and bool(getattr(n, _, False)))
     else:
-        n2tooltip = lambda n, categories: \
-            ', '.join('{}:{}'.format(cat, getattr(n, cat)) for cat in categories
-                      if hasattr(n, cat) and bool(getattr(n, cat, False)))
+        n2tooltip = lambda n, cats: \
+            ', '.join('{}:{}'.format(_, getattr(n, _)) for _ in cats if hasattr(n, _) and bool(getattr(n, _, False)))
 
     if html:
         save_as_cytoscape_html(tree, html, categories=categories, name2colour=name2colour, n2tooltip=n2tooltip,
@@ -311,23 +302,23 @@ def past_vis(tree, res_annotations, html_compressed=None, html=None, data_sep='\
                                name2colour=name2colour, add_fake_nodes=False, n2tooltip=n2tooltip)
 
 
-if '__main__' == __name__:
+def main():
     import argparse
 
     parser = argparse.ArgumentParser(description="Visualisation of annotated phylogenetic trees (as html maps).")
 
     annotation_group = parser.add_argument_group('annotation-related arguments')
-    annotation_group.add_argument('--data', required=True, type=str,
+    annotation_group.add_argument('-d', '--data', required=True, type=str,
                                   help="the annotation file in tab/csv format with the first row "
                                        "containing the column names.")
-    annotation_group.add_argument('--data_sep', required=False, type=str, default='\t',
+    annotation_group.add_argument('-s', '--data_sep', required=False, type=str, default='\t',
                                   help="the column separator for the data table. "
-                                       "By default is set to tab, i.e. for tab file. " \
+                                       "By default is set to tab, i.e. for tab file. " 
                                        "Set it to ',' if your file is csv.")
-    annotation_group.add_argument('--id_index', required=False, type=int, default=0,
+    annotation_group.add_argument('-i', '--id_index', required=False, type=int, default=0,
                                   help="the index of the column in the data table that contains the tree tip names, "
                                        "indices start from zero (by default is set to 0).")
-    annotation_group.add_argument('--columns', nargs='*',
+    annotation_group.add_argument('-c', '--columns', nargs='*',
                                   help="names of the data table columns that contain states "
                                        "to be analysed with PASTML. "
                                        "If neither columns nor copy_columns are specified, "
@@ -339,10 +330,10 @@ if '__main__' == __name__:
                                   type=str)
 
     tree_group = parser.add_argument_group('tree-related arguments')
-    tree_group.add_argument('--tree', help="the input tree in newick format.", type=str, required=True)
+    tree_group.add_argument('-t', '--tree', help="the input tree in newick format.", type=str, required=True)
 
     pastml_group = parser.add_argument_group('ancestral-state inference-related arguments')
-    pastml_group.add_argument('--model', required=False, default='JC', type=str,
+    pastml_group.add_argument('-m', '--model', required=False, default='JC', type=str,
                               help="the evolutionary model to be used by PASTML (can be JC or F81).")
     pastml_group.add_argument('--work_dir', required=False, default=None, type=str,
                               help="the working dir for PASTML to put intermediate files into "
@@ -352,23 +343,29 @@ if '__main__' == __name__:
                                    "when possible")
 
     vis_group = parser.add_argument_group('visualisation-related arguments')
-    vis_group.add_argument('--name_column', type=str, default=None,
+    vis_group.add_argument('-n', '--name_column', type=str, default=None,
                            help="name of the data table column to be used for node names "
                                 "in the compressed map visualisation"
                                 "(must be one of those specified in columns or copy_columns if they are specified)."
                                 "If the data table contains only one column it will be used by default.")
-    vis_group.add_argument('--all', action='store_true', help="Keep all the nodes in the compressed map visualisation, "
-                                                              "even the minor ones.")
+    vis_group.add_argument('-a', '--all', action='store_true',
+                           help="Keep all the nodes in the compressed map visualisation, "
+                                "even the minor ones.")
 
     out_group = parser.add_argument_group('output-related arguments')
-    out_group.add_argument('--out_data', required=False, type=str,
+    out_group.add_argument('-o', '--out_data', required=False, type=str,
                            help="the output annotation file with the states inferred by PASTML.")
-    out_group.add_argument('--html_compressed', required=False, default=None, type=str,
+    out_group.add_argument('-p', '--html_compressed', required=False, default=None, type=str,
                            help="the output summary map visualisation file (html).")
-    out_group.add_argument('--html', required=False, default=None, type=str,
+    out_group.add_argument('-l', '--html', required=False, default=None, type=str,
                            help="the output tree visualisation file (html).")
 
-    parser.add_argument('--verbose', action='store_true', help="print information on the progress of the analysis")
+    parser.add_argument('-v', '--verbose', action='store_true',
+                        help="print information on the progress of the analysis")
     params = parser.parse_args()
 
     pastml_pipeline(**vars(params))
+
+
+if '__main__' == __name__:
+    main()
